class Color:
    def __init__(self):
        self.colors = ['information', 'good', 'bad', 'other']
        self.information = '\x1b[33m[!]\x1b[0m'
        self.good = '\x1b[32m[+]\x1b[0m'
        self.bad = '\x1b[31m[-]\x1b[0m'
        self.other = '\x1b[34m[*]\x1b[0m'



def merge(xpath: str, ypath: str) -> str:
    xpath = urlerslasher(xpath)
    ypath = unstarter(ypath, '/')
    return xpath + ypath

def urlerslasher(xpath: str) -> str:
    return ender(urler(xpath), '/')

def starter(xpath:str, ypath: str) -> str:
    if xpath[0] != ypath:
        return ypath + xpath
    return xpath

def unstarter(xpath:str, ypath: str) -> str:
    if xpath[0] == ypath:
        return xpath[1:]
    return xpath

def ender(xpath: str, ypath: str) -> str:
    if xpath[-1] != ypath:
        return xpath + ypath
    return xpath

def unender(xpath: str, ypath: str) -> str:
    if xpath[-1] == ypath:
        return xpath[:-1]
    return xpath

def urler(xpath: str) -> str:
    if not xpath.startswith('http://') and not xpath.startswith('https://'):
        return "http://" + xpath
    return xpath

def unurler(xpath: str) -> str:
    if '://' in xpath:
        return xpath.split('://')[-1]
    return xpath



#!/usr/bin/python3

from argparse import ArgumentParser
from concurrent.futures import ThreadPoolExecutor

from Nemesis.lib.Extract import extract_url
from Nemesis.lib.Functions import starter

def main():
    parser = ArgumentParser(description='\x1b[33mNemesis\x1b[0m', epilog='\x1b[33mEnjoy bug hunting\x1b[0m')
    input_group = parser.add_mutually_exclusive_group()
    input_group.add_argument('---', '---', action="store_true", dest="stdin", help="Stdin")
    input_group.add_argument('-w', '--wordlist', type=str, help='Absolute path of wordlist')
    input_group.add_argument('-u', '--url', type=str, help="url to scan")
    #parser.add_argument('-d', '--domain', type=str, help="Domain")
    parser.add_argument('-o', '--output', type=str, help="Output file")
    parser.add_argument('-e', '--enable-entropy', action="store_true", help="Enable entropy search")
    parser.add_argument('-t', '--threads', type=int, help="Number of threads")
    parser.add_argument('-b', '--banner', action="store_true", help="Print banner and exit")
    argv = parser.parse_args()
    input_wordlist = starter(argv)

    for input_url in input_wordlist:
        extract_url(input_url)
#     with ThreadPoolExecutor(max_workers=argv.threads) as submitter:
        # future_objects = [submitter.submit(extract_url, input_word) for input_word in input_wordlist]
        # if argv.output_directory:
            # pass
            # #output_writer(argv.domain, future_objects, filepath=argv.output_directory)
        # elif argv.output:
            # pass
            # #output_writer(argv.output, future_objects, filepath=None)

if __name__ == "__main__":
    main()
